Date: 08 8, 2001 12:53:57 PM

# Creating Analyzers

To create an analyzer:

1. From the File menu, select New Analyzer.

2. In the New Analyzer dialog, give the analyzer a name. This name will be used to organize the analyzer project. VisualText automatically assigns a .ana extension to the name to mark it as the analyzer project file. You use the .ana file to open the analyzer project.

3. Specify the drive and folder where you want the analyzer project and its files to be created in Location. The application directory defaults to c:\apps. (You can change the default application directory in the Preferences dialog.)

4. For Template, select one of the templates under Type. (For more on templates, see Analyzer Templates.)

5. Click OK to finish creating the analyzer project.

## See Also

Opening analyzers
Structure of analyzer projects
Setting VisualText Preferences